<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>BatmonWidget</name>
    <message>
        <location filename="BatmonWidget.cpp" line="94"/>
        <source>girl</source>
        <translation>女の子</translation>
    </message>
    <message>
        <location filename="BatmonWidget.cpp" line="104"/>
        <source>pengui</source>
        <translation>りもペンギン</translation>
    </message>
    <message>
        <location filename="BatmonWidget.cpp" line="133"/>
        <source>Hide while charging</source>
        <translation>充電中は表示しない</translation>
    </message>
    <message>
        <location filename="BatmonWidget.cpp" line="143"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="BatmonWidget.cpp" line="155"/>
        <source>APM Battery Monitor</source>
        <translation>APM ばってりーもにたー</translation>
    </message>
    <message>
        <location filename="BatmonWidget.cpp" line="278"/>
        <source>charging: %1 [%]</source>
        <translation>充電中: %1 [%]</translation>
    </message>
    <message>
        <location filename="BatmonWidget.cpp" line="283"/>
        <source>remaining: %1 [%]</source>
        <translation>容量: %1 [%]</translation>
    </message>
    <message>
        <location filename="BatmonWidget.cpp" line="285"/>
        <source>remaining: %1 [h] (%2 [%])</source>
        <translation>残り: %1 [h] (%2 [%])</translation>
    </message>
    <message>
        <location filename="BatmonWidget.cpp" line="291"/>
        <source>unknown system</source>
        <translation>不明なシステム</translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <location filename="BatmonWidget.cpp" line="142"/>
        <source>Quit</source>
        <translation>終了</translation>
    </message>
</context>
</TS>
